package org.example;

import org.hibernate.SessionFactory;
import org.hibernate.cfg.Configuration;
import java.util.Scanner;

public class Main {
    public static void main(String[] args) {
        // Konfiguracja Hibernate z pliku hibernate.cfg.xml
        Configuration configuration = new Configuration();
        configuration.configure("hibernate.cfg.xml");

        // Utworzenie sesji Hibernate
        SessionFactory sessionFactory = configuration.buildSessionFactory();

        // Utworzenie instancji LibraryService
        LibraryService libraryService = new LibraryService(sessionFactory);

        Scanner scanner = new Scanner(System.in);

        while (true) {
            System.out.println("-- BIBLIOTEKA --");
            System.out.println("1. Wypisz książki danego autora");
            System.out.println("2. Wypisz wypożyczenia użytkownika");
            System.out.println("3. Wypisz dostępne książki");
            System.out.println("4. Wyjście");

            System.out.print("Wybierz opcję: ");
            int choice = scanner.nextInt();

            switch (choice) {
                case 1:
                    libraryService.printAllAuthors();
                    System.out.print("Podaj ID autora: ");
                    long authorId = scanner.nextLong();
                    libraryService.printBooksByAuthor(authorId);
                    break;
                case 2:
                    System.out.print("Podaj ID użytkownika: ");
                    long userId = scanner.nextLong();
                    if (!libraryService.hasBorrows(userId)) {
                        System.out.println("Użytkownik o ID " + userId + " nie ma żadnych wypożyczeń.");
                    } else {
                        int currentPage = 1;
                        boolean browsing = true;
                        while (browsing) {
                            libraryService.printBorrowsByUserId(userId, currentPage);
                            System.out.println("Aktualna strona: " + currentPage);
                            System.out.println("1. Następna strona");
                            System.out.println("2. Poprzednia strona");
                            System.out.println("3. Wyjście ze stronicowania");
                            System.out.print("Wybierz opcję: ");
                            int pageChoice = scanner.nextInt();
                            switch (pageChoice) {
                                case 1:
                                    currentPage++;
                                    break;
                                case 2:
                                    currentPage = Math.max(1, currentPage - 1);
                                    break;
                                case 3:
                                    browsing = false;
                                    break;
                            }
                        }
                    }
                    break;
                case 3:
                    libraryService.printAvailableBooks();
                    break;
                case 4:
                    System.out.println("> EXIT <");
                    sessionFactory.close();
                    System.exit(0);
                    break;
                default:
                    System.out.println("Nieprawidłowa opcja, spróbuj ponownie.");
            }
        }
    }
}